paymentcustomer

package
v0.0.0-...-9d82fa0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 18, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the paymentcustomer type in the database.
	Label = "payment_customer"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldProviderCustomerID holds the string denoting the provider_customer_id field in the database.
	FieldProviderCustomerID = "provider_customer_id"
	// FieldProvider holds the string denoting the provider field in the database.
	FieldProvider = "provider"
	// FieldEmail holds the string denoting the email field in the database.
	FieldEmail = "email"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldMetadata holds the string denoting the metadata field in the database.
	FieldMetadata = "metadata"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// EdgePaymentIntents holds the string denoting the payment_intents edge name in mutations.
	EdgePaymentIntents = "payment_intents"
	// EdgeSubscriptions holds the string denoting the subscriptions edge name in mutations.
	EdgeSubscriptions = "subscriptions"
	// EdgePaymentMethods holds the string denoting the payment_methods edge name in mutations.
	EdgePaymentMethods = "payment_methods"
	// Table holds the table name of the paymentcustomer in the database.
	Table = "payment_customers"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "users"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "payment_customer_user"
	// PaymentIntentsTable is the table that holds the payment_intents relation/edge.
	PaymentIntentsTable = "payment_intents"
	// PaymentIntentsInverseTable is the table name for the PaymentIntent entity.
	// It exists in this package in order to avoid circular dependency with the "paymentintent" package.
	PaymentIntentsInverseTable = "payment_intents"
	// PaymentIntentsColumn is the table column denoting the payment_intents relation/edge.
	PaymentIntentsColumn = "payment_customer_payment_intents"
	// SubscriptionsTable is the table that holds the subscriptions relation/edge.
	SubscriptionsTable = "subscriptions"
	// SubscriptionsInverseTable is the table name for the Subscription entity.
	// It exists in this package in order to avoid circular dependency with the "subscription" package.
	SubscriptionsInverseTable = "subscriptions"
	// SubscriptionsColumn is the table column denoting the subscriptions relation/edge.
	SubscriptionsColumn = "payment_customer_subscriptions"
	// PaymentMethodsTable is the table that holds the payment_methods relation/edge.
	PaymentMethodsTable = "payment_methods"
	// PaymentMethodsInverseTable is the table name for the PaymentMethod entity.
	// It exists in this package in order to avoid circular dependency with the "paymentmethod" package.
	PaymentMethodsInverseTable = "payment_methods"
	// PaymentMethodsColumn is the table column denoting the payment_methods relation/edge.
	PaymentMethodsColumn = "payment_customer_payment_methods"
)

Variables

var (
	// ProviderCustomerIDValidator is a validator for the "provider_customer_id" field. It is called by the builders before save.
	ProviderCustomerIDValidator func(string) error
	// DefaultProvider holds the default value on creation for the "provider" field.
	DefaultProvider string
	// ProviderValidator is a validator for the "provider" field. It is called by the builders before save.
	ProviderValidator func(string) error
	// EmailValidator is a validator for the "email" field. It is called by the builders before save.
	EmailValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
)

Columns holds all SQL columns for paymentcustomer fields.

Functions

func And

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.PaymentCustomer

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.PaymentCustomer

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.PaymentCustomer

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.PaymentCustomer

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.PaymentCustomer

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.PaymentCustomer

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.PaymentCustomer

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.PaymentCustomer

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.PaymentCustomer

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func Email

Email applies equality check predicate on the "email" field. It's identical to EmailEQ.

func EmailContains

func EmailContains(v string) predicate.PaymentCustomer

EmailContains applies the Contains predicate on the "email" field.

func EmailContainsFold

func EmailContainsFold(v string) predicate.PaymentCustomer

EmailContainsFold applies the ContainsFold predicate on the "email" field.

func EmailEQ

func EmailEQ(v string) predicate.PaymentCustomer

EmailEQ applies the EQ predicate on the "email" field.

func EmailEqualFold

func EmailEqualFold(v string) predicate.PaymentCustomer

EmailEqualFold applies the EqualFold predicate on the "email" field.

func EmailGT

func EmailGT(v string) predicate.PaymentCustomer

EmailGT applies the GT predicate on the "email" field.

func EmailGTE

func EmailGTE(v string) predicate.PaymentCustomer

EmailGTE applies the GTE predicate on the "email" field.

func EmailHasPrefix

func EmailHasPrefix(v string) predicate.PaymentCustomer

EmailHasPrefix applies the HasPrefix predicate on the "email" field.

func EmailHasSuffix

func EmailHasSuffix(v string) predicate.PaymentCustomer

EmailHasSuffix applies the HasSuffix predicate on the "email" field.

func EmailIn

func EmailIn(vs ...string) predicate.PaymentCustomer

EmailIn applies the In predicate on the "email" field.

func EmailLT

func EmailLT(v string) predicate.PaymentCustomer

EmailLT applies the LT predicate on the "email" field.

func EmailLTE

func EmailLTE(v string) predicate.PaymentCustomer

EmailLTE applies the LTE predicate on the "email" field.

func EmailNEQ

func EmailNEQ(v string) predicate.PaymentCustomer

EmailNEQ applies the NEQ predicate on the "email" field.

func EmailNotIn

func EmailNotIn(vs ...string) predicate.PaymentCustomer

EmailNotIn applies the NotIn predicate on the "email" field.

func HasPaymentIntents

func HasPaymentIntents() predicate.PaymentCustomer

HasPaymentIntents applies the HasEdge predicate on the "payment_intents" edge.

func HasPaymentIntentsWith

func HasPaymentIntentsWith(preds ...predicate.PaymentIntent) predicate.PaymentCustomer

HasPaymentIntentsWith applies the HasEdge predicate on the "payment_intents" edge with a given conditions (other predicates).

func HasPaymentMethods

func HasPaymentMethods() predicate.PaymentCustomer

HasPaymentMethods applies the HasEdge predicate on the "payment_methods" edge.

func HasPaymentMethodsWith

func HasPaymentMethodsWith(preds ...predicate.PaymentMethod) predicate.PaymentCustomer

HasPaymentMethodsWith applies the HasEdge predicate on the "payment_methods" edge with a given conditions (other predicates).

func HasSubscriptions

func HasSubscriptions() predicate.PaymentCustomer

HasSubscriptions applies the HasEdge predicate on the "subscriptions" edge.

func HasSubscriptionsWith

func HasSubscriptionsWith(preds ...predicate.Subscription) predicate.PaymentCustomer

HasSubscriptionsWith applies the HasEdge predicate on the "subscriptions" edge with a given conditions (other predicates).

func HasUser

func HasUser() predicate.PaymentCustomer

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.PaymentCustomer

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.PaymentCustomer

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.PaymentCustomer

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.PaymentCustomer

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.PaymentCustomer

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.PaymentCustomer

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.PaymentCustomer

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.PaymentCustomer

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.PaymentCustomer

IDNotIn applies the NotIn predicate on the ID field.

func MetadataIsNil

func MetadataIsNil() predicate.PaymentCustomer

MetadataIsNil applies the IsNil predicate on the "metadata" field.

func MetadataNotNil

func MetadataNotNil() predicate.PaymentCustomer

MetadataNotNil applies the NotNil predicate on the "metadata" field.

func Name

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.PaymentCustomer

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.PaymentCustomer

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.PaymentCustomer

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.PaymentCustomer

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.PaymentCustomer

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.PaymentCustomer

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.PaymentCustomer

NameIn applies the In predicate on the "name" field.

func NameIsNil

func NameIsNil() predicate.PaymentCustomer

NameIsNil applies the IsNil predicate on the "name" field.

func NameLT

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.PaymentCustomer

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.PaymentCustomer

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.PaymentCustomer

NameNotIn applies the NotIn predicate on the "name" field.

func NameNotNil

func NameNotNil() predicate.PaymentCustomer

NameNotNil applies the NotNil predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func Provider

func Provider(v string) predicate.PaymentCustomer

Provider applies equality check predicate on the "provider" field. It's identical to ProviderEQ.

func ProviderContains

func ProviderContains(v string) predicate.PaymentCustomer

ProviderContains applies the Contains predicate on the "provider" field.

func ProviderContainsFold

func ProviderContainsFold(v string) predicate.PaymentCustomer

ProviderContainsFold applies the ContainsFold predicate on the "provider" field.

func ProviderCustomerID

func ProviderCustomerID(v string) predicate.PaymentCustomer

ProviderCustomerID applies equality check predicate on the "provider_customer_id" field. It's identical to ProviderCustomerIDEQ.

func ProviderCustomerIDContains

func ProviderCustomerIDContains(v string) predicate.PaymentCustomer

ProviderCustomerIDContains applies the Contains predicate on the "provider_customer_id" field.

func ProviderCustomerIDContainsFold

func ProviderCustomerIDContainsFold(v string) predicate.PaymentCustomer

ProviderCustomerIDContainsFold applies the ContainsFold predicate on the "provider_customer_id" field.

func ProviderCustomerIDEQ

func ProviderCustomerIDEQ(v string) predicate.PaymentCustomer

ProviderCustomerIDEQ applies the EQ predicate on the "provider_customer_id" field.

func ProviderCustomerIDEqualFold

func ProviderCustomerIDEqualFold(v string) predicate.PaymentCustomer

ProviderCustomerIDEqualFold applies the EqualFold predicate on the "provider_customer_id" field.

func ProviderCustomerIDGT

func ProviderCustomerIDGT(v string) predicate.PaymentCustomer

ProviderCustomerIDGT applies the GT predicate on the "provider_customer_id" field.

func ProviderCustomerIDGTE

func ProviderCustomerIDGTE(v string) predicate.PaymentCustomer

ProviderCustomerIDGTE applies the GTE predicate on the "provider_customer_id" field.

func ProviderCustomerIDHasPrefix

func ProviderCustomerIDHasPrefix(v string) predicate.PaymentCustomer

ProviderCustomerIDHasPrefix applies the HasPrefix predicate on the "provider_customer_id" field.

func ProviderCustomerIDHasSuffix

func ProviderCustomerIDHasSuffix(v string) predicate.PaymentCustomer

ProviderCustomerIDHasSuffix applies the HasSuffix predicate on the "provider_customer_id" field.

func ProviderCustomerIDIn

func ProviderCustomerIDIn(vs ...string) predicate.PaymentCustomer

ProviderCustomerIDIn applies the In predicate on the "provider_customer_id" field.

func ProviderCustomerIDLT

func ProviderCustomerIDLT(v string) predicate.PaymentCustomer

ProviderCustomerIDLT applies the LT predicate on the "provider_customer_id" field.

func ProviderCustomerIDLTE

func ProviderCustomerIDLTE(v string) predicate.PaymentCustomer

ProviderCustomerIDLTE applies the LTE predicate on the "provider_customer_id" field.

func ProviderCustomerIDNEQ

func ProviderCustomerIDNEQ(v string) predicate.PaymentCustomer

ProviderCustomerIDNEQ applies the NEQ predicate on the "provider_customer_id" field.

func ProviderCustomerIDNotIn

func ProviderCustomerIDNotIn(vs ...string) predicate.PaymentCustomer

ProviderCustomerIDNotIn applies the NotIn predicate on the "provider_customer_id" field.

func ProviderEQ

func ProviderEQ(v string) predicate.PaymentCustomer

ProviderEQ applies the EQ predicate on the "provider" field.

func ProviderEqualFold

func ProviderEqualFold(v string) predicate.PaymentCustomer

ProviderEqualFold applies the EqualFold predicate on the "provider" field.

func ProviderGT

func ProviderGT(v string) predicate.PaymentCustomer

ProviderGT applies the GT predicate on the "provider" field.

func ProviderGTE

func ProviderGTE(v string) predicate.PaymentCustomer

ProviderGTE applies the GTE predicate on the "provider" field.

func ProviderHasPrefix

func ProviderHasPrefix(v string) predicate.PaymentCustomer

ProviderHasPrefix applies the HasPrefix predicate on the "provider" field.

func ProviderHasSuffix

func ProviderHasSuffix(v string) predicate.PaymentCustomer

ProviderHasSuffix applies the HasSuffix predicate on the "provider" field.

func ProviderIn

func ProviderIn(vs ...string) predicate.PaymentCustomer

ProviderIn applies the In predicate on the "provider" field.

func ProviderLT

func ProviderLT(v string) predicate.PaymentCustomer

ProviderLT applies the LT predicate on the "provider" field.

func ProviderLTE

func ProviderLTE(v string) predicate.PaymentCustomer

ProviderLTE applies the LTE predicate on the "provider" field.

func ProviderNEQ

func ProviderNEQ(v string) predicate.PaymentCustomer

ProviderNEQ applies the NEQ predicate on the "provider" field.

func ProviderNotIn

func ProviderNotIn(vs ...string) predicate.PaymentCustomer

ProviderNotIn applies the NotIn predicate on the "provider" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.PaymentCustomer

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.PaymentCustomer

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.PaymentCustomer

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.PaymentCustomer

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.PaymentCustomer

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.PaymentCustomer

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.PaymentCustomer

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.PaymentCustomer

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.PaymentCustomer

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the PaymentCustomer queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByEmail

func ByEmail(opts ...sql.OrderTermOption) OrderOption

ByEmail orders the results by the email field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByPaymentIntents

func ByPaymentIntents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByPaymentIntents orders the results by payment_intents terms.

func ByPaymentIntentsCount

func ByPaymentIntentsCount(opts ...sql.OrderTermOption) OrderOption

ByPaymentIntentsCount orders the results by payment_intents count.

func ByPaymentMethods

func ByPaymentMethods(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByPaymentMethods orders the results by payment_methods terms.

func ByPaymentMethodsCount

func ByPaymentMethodsCount(opts ...sql.OrderTermOption) OrderOption

ByPaymentMethodsCount orders the results by payment_methods count.

func ByProvider

func ByProvider(opts ...sql.OrderTermOption) OrderOption

ByProvider orders the results by the provider field.

func ByProviderCustomerID

func ByProviderCustomerID(opts ...sql.OrderTermOption) OrderOption

ByProviderCustomerID orders the results by the provider_customer_id field.

func BySubscriptions

func BySubscriptions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

BySubscriptions orders the results by subscriptions terms.

func BySubscriptionsCount

func BySubscriptionsCount(opts ...sql.OrderTermOption) OrderOption

BySubscriptionsCount orders the results by subscriptions count.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

Jump to