schema

package
v0.0.0-...-9d82fa0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 18, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ChatBan

type ChatBan struct {
	ent.Schema
}

ChatBan holds the schema definition for the ChatBan entity.

func (ChatBan) Edges

func (ChatBan) Edges() []ent.Edge

Edges of the ChatBan.

func (ChatBan) Fields

func (ChatBan) Fields() []ent.Field

Fields of the ChatBan.

type ChatMessage

type ChatMessage struct {
	ent.Schema
}

ChatMessage holds the schema definition for the ChatMessage entity.

func (ChatMessage) Edges

func (ChatMessage) Edges() []ent.Edge

Edges of the ChatMessage.

func (ChatMessage) Fields

func (ChatMessage) Fields() []ent.Field

Fields of the ChatMessage.

type ChatRoom

type ChatRoom struct {
	ent.Schema
}

ChatRoom holds the schema definition for the ChatRoom entity.

func (ChatRoom) Edges

func (ChatRoom) Edges() []ent.Edge

Edges of the ChatRoom.

func (ChatRoom) Fields

func (ChatRoom) Fields() []ent.Field

Fields of the ChatRoom.

type PasswordToken

type PasswordToken struct {
	ent.Schema
}

PasswordToken holds the schema definition for the PasswordToken entity.

func (PasswordToken) Edges

func (PasswordToken) Edges() []ent.Edge

Edges of the PasswordToken.

func (PasswordToken) Fields

func (PasswordToken) Fields() []ent.Field

Fields of the PasswordToken.

func (PasswordToken) Hooks

func (PasswordToken) Hooks() []ent.Hook

Hooks of the PasswordToken.

type PaymentCustomer

type PaymentCustomer struct {
	ent.Schema
}

PaymentCustomer holds the schema definition for the PaymentCustomer entity.

func (PaymentCustomer) Edges

func (PaymentCustomer) Edges() []ent.Edge

Edges of the PaymentCustomer.

func (PaymentCustomer) Fields

func (PaymentCustomer) Fields() []ent.Field

Fields of the PaymentCustomer.

type PaymentIntent

type PaymentIntent struct {
	ent.Schema
}

PaymentIntent holds the schema definition for the PaymentIntent entity.

func (PaymentIntent) Edges

func (PaymentIntent) Edges() []ent.Edge

Edges of the PaymentIntent.

func (PaymentIntent) Fields

func (PaymentIntent) Fields() []ent.Field

Fields of the PaymentIntent.

type PaymentMethod

type PaymentMethod struct {
	ent.Schema
}

PaymentMethod holds the schema definition for the PaymentMethod entity.

func (PaymentMethod) Edges

func (PaymentMethod) Edges() []ent.Edge

Edges of the PaymentMethod.

func (PaymentMethod) Fields

func (PaymentMethod) Fields() []ent.Field

Fields of the PaymentMethod.

type Subscription

type Subscription struct {
	ent.Schema
}

Subscription holds the schema definition for the Subscription entity.

func (Subscription) Edges

func (Subscription) Edges() []ent.Edge

Edges of the Subscription.

func (Subscription) Fields

func (Subscription) Fields() []ent.Field

Fields of the Subscription.

type User

type User struct {
	ent.Schema
}

User holds the schema definition for the User entity.

func (User) Edges

func (User) Edges() []ent.Edge

Edges of the User.

func (User) Fields

func (User) Fields() []ent.Field

Fields of the User.

func (User) Hooks

func (User) Hooks() []ent.Hook

Hooks of the User.

Jump to