Documentation
¶
Overview ¶
Code generated by ent, DO NOT EDIT.
Code generated by ent, DO NOT EDIT.
Index ¶
- func FieldLabel(name string) string
- func GetEntityTypeNames() []string
- type ChatBan
- type ChatMessage
- type ChatRoom
- type EntityList
- type EntityValues
- type Extension
- type Handler
- func (h *Handler) ChatBanCreate(ctx echo.Context) error
- func (h *Handler) ChatBanDelete(ctx echo.Context, id int) error
- func (h *Handler) ChatBanGet(ctx echo.Context, id int) (url.Values, error)
- func (h *Handler) ChatBanList(ctx echo.Context) (*EntityList, error)
- func (h *Handler) ChatBanUpdate(ctx echo.Context, id int) error
- func (h *Handler) ChatMessageCreate(ctx echo.Context) error
- func (h *Handler) ChatMessageDelete(ctx echo.Context, id int) error
- func (h *Handler) ChatMessageGet(ctx echo.Context, id int) (url.Values, error)
- func (h *Handler) ChatMessageList(ctx echo.Context) (*EntityList, error)
- func (h *Handler) ChatMessageUpdate(ctx echo.Context, id int) error
- func (h *Handler) ChatRoomCreate(ctx echo.Context) error
- func (h *Handler) ChatRoomDelete(ctx echo.Context, id int) error
- func (h *Handler) ChatRoomGet(ctx echo.Context, id int) (url.Values, error)
- func (h *Handler) ChatRoomList(ctx echo.Context) (*EntityList, error)
- func (h *Handler) ChatRoomUpdate(ctx echo.Context, id int) error
- func (h *Handler) Create(ctx echo.Context, entityType string) error
- func (h *Handler) Delete(ctx echo.Context, entityType string, id int) error
- func (h *Handler) Get(ctx echo.Context, entityType string, id int) (url.Values, error)
- func (h *Handler) List(ctx echo.Context, entityType string) (*EntityList, error)
- func (h *Handler) PasswordTokenCreate(ctx echo.Context) error
- func (h *Handler) PasswordTokenDelete(ctx echo.Context, id int) error
- func (h *Handler) PasswordTokenGet(ctx echo.Context, id int) (url.Values, error)
- func (h *Handler) PasswordTokenList(ctx echo.Context) (*EntityList, error)
- func (h *Handler) PasswordTokenUpdate(ctx echo.Context, id int) error
- func (h *Handler) PaymentCustomerCreate(ctx echo.Context) error
- func (h *Handler) PaymentCustomerDelete(ctx echo.Context, id int) error
- func (h *Handler) PaymentCustomerGet(ctx echo.Context, id int) (url.Values, error)
- func (h *Handler) PaymentCustomerList(ctx echo.Context) (*EntityList, error)
- func (h *Handler) PaymentCustomerUpdate(ctx echo.Context, id int) error
- func (h *Handler) PaymentIntentCreate(ctx echo.Context) error
- func (h *Handler) PaymentIntentDelete(ctx echo.Context, id int) error
- func (h *Handler) PaymentIntentGet(ctx echo.Context, id int) (url.Values, error)
- func (h *Handler) PaymentIntentList(ctx echo.Context) (*EntityList, error)
- func (h *Handler) PaymentIntentUpdate(ctx echo.Context, id int) error
- func (h *Handler) PaymentMethodCreate(ctx echo.Context) error
- func (h *Handler) PaymentMethodDelete(ctx echo.Context, id int) error
- func (h *Handler) PaymentMethodGet(ctx echo.Context, id int) (url.Values, error)
- func (h *Handler) PaymentMethodList(ctx echo.Context) (*EntityList, error)
- func (h *Handler) PaymentMethodUpdate(ctx echo.Context, id int) error
- func (h *Handler) SubscriptionCreate(ctx echo.Context) error
- func (h *Handler) SubscriptionDelete(ctx echo.Context, id int) error
- func (h *Handler) SubscriptionGet(ctx echo.Context, id int) (url.Values, error)
- func (h *Handler) SubscriptionList(ctx echo.Context) (*EntityList, error)
- func (h *Handler) SubscriptionUpdate(ctx echo.Context, id int) error
- func (h *Handler) Update(ctx echo.Context, entityType string, id int) error
- func (h *Handler) UserCreate(ctx echo.Context) error
- func (h *Handler) UserDelete(ctx echo.Context, id int) error
- func (h *Handler) UserGet(ctx echo.Context, id int) (url.Values, error)
- func (h *Handler) UserList(ctx echo.Context) (*EntityList, error)
- func (h *Handler) UserUpdate(ctx echo.Context, id int) error
- type HandlerConfig
- type PasswordToken
- type PaymentCustomer
- type PaymentIntent
- type PaymentMethod
- type Subscription
- type User
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FieldLabel ¶
FieldLabel provides a label for an entity field name (ie, user_id -> User ID).
func GetEntityTypeNames ¶
func GetEntityTypeNames() []string
Types ¶
type ChatMessage ¶
type EntityList ¶
type EntityList struct {
Columns []string
Entities []EntityValues
Page int
HasNextPage bool
}
type EntityValues ¶
type Extension ¶
type Extension struct {
entc.DefaultExtension
}
Extension is the Ent extension that generates code to support the entity admin panel.
type Handler ¶
type Handler struct {
Config HandlerConfig
// contains filtered or unexported fields
}
func NewHandler ¶
func NewHandler(client *ent.Client, cfg HandlerConfig) *Handler
func (*Handler) ChatBanGet ¶
func (*Handler) ChatBanList ¶
func (h *Handler) ChatBanList(ctx echo.Context) (*EntityList, error)
func (*Handler) ChatMessageDelete ¶
func (*Handler) ChatMessageGet ¶
func (*Handler) ChatMessageList ¶
func (h *Handler) ChatMessageList(ctx echo.Context) (*EntityList, error)
func (*Handler) ChatMessageUpdate ¶
func (*Handler) ChatRoomGet ¶
func (*Handler) ChatRoomList ¶
func (h *Handler) ChatRoomList(ctx echo.Context) (*EntityList, error)
func (*Handler) PasswordTokenDelete ¶
func (*Handler) PasswordTokenGet ¶
func (*Handler) PasswordTokenList ¶
func (h *Handler) PasswordTokenList(ctx echo.Context) (*EntityList, error)
func (*Handler) PasswordTokenUpdate ¶
func (*Handler) PaymentCustomerCreate ¶
func (*Handler) PaymentCustomerDelete ¶
func (*Handler) PaymentCustomerGet ¶
func (*Handler) PaymentCustomerList ¶
func (h *Handler) PaymentCustomerList(ctx echo.Context) (*EntityList, error)
func (*Handler) PaymentCustomerUpdate ¶
func (*Handler) PaymentIntentDelete ¶
func (*Handler) PaymentIntentGet ¶
func (*Handler) PaymentIntentList ¶
func (h *Handler) PaymentIntentList(ctx echo.Context) (*EntityList, error)
func (*Handler) PaymentIntentUpdate ¶
func (*Handler) PaymentMethodDelete ¶
func (*Handler) PaymentMethodGet ¶
func (*Handler) PaymentMethodList ¶
func (h *Handler) PaymentMethodList(ctx echo.Context) (*EntityList, error)
func (*Handler) PaymentMethodUpdate ¶
func (*Handler) SubscriptionDelete ¶
func (*Handler) SubscriptionGet ¶
func (*Handler) SubscriptionList ¶
func (h *Handler) SubscriptionList(ctx echo.Context) (*EntityList, error)
func (*Handler) SubscriptionUpdate ¶
type HandlerConfig ¶
type PasswordToken ¶
type PaymentCustomer ¶
type PaymentCustomer struct {
ProviderCustomerID string `form:"provider_customer_id"`
Provider *string `form:"provider"`
Email string `form:"email"`
Name *string `form:"name"`
Metadata *map[string]interface{} `form:"metadata"`
CreatedAt *time.Time `form:"created_at"`
UpdatedAt *time.Time `form:"updated_at"`
}
type PaymentIntent ¶
type PaymentIntent struct {
ProviderPaymentIntentID string `form:"provider_payment_intent_id"`
Provider *string `form:"provider"`
Status *paymentintent.Status `form:"status"`
Amount int64 `form:"amount"`
Currency *string `form:"currency"`
Description *string `form:"description"`
ClientSecret *string `form:"client_secret"`
Metadata *map[string]interface{} `form:"metadata"`
CreatedAt *time.Time `form:"created_at"`
UpdatedAt *time.Time `form:"updated_at"`
}
type PaymentMethod ¶
type PaymentMethod struct {
ProviderPaymentMethodID string `form:"provider_payment_method_id"`
Provider *string `form:"provider"`
Type *paymentmethod.Type `form:"type"`
LastFour *string `form:"last_four"`
Brand *string `form:"brand"`
ExpMonth *int `form:"exp_month"`
ExpYear *int `form:"exp_year"`
IsDefault bool `form:"is_default"`
Metadata *map[string]interface{} `form:"metadata"`
CreatedAt *time.Time `form:"created_at"`
UpdatedAt *time.Time `form:"updated_at"`
}
type Subscription ¶
type Subscription struct {
ProviderSubscriptionID string `form:"provider_subscription_id"`
Provider *string `form:"provider"`
Status *subscription.Status `form:"status"`
PriceID string `form:"price_id"`
Amount int64 `form:"amount"`
Currency *string `form:"currency"`
Interval subscription.Interval `form:"interval"`
IntervalCount *int `form:"interval_count"`
CurrentPeriodStart *time.Time `form:"current_period_start"`
CurrentPeriodEnd *time.Time `form:"current_period_end"`
TrialStart *time.Time `form:"trial_start"`
TrialEnd *time.Time `form:"trial_end"`
CanceledAt *time.Time `form:"canceled_at"`
EndedAt *time.Time `form:"ended_at"`
Metadata *map[string]interface{} `form:"metadata"`
CreatedAt *time.Time `form:"created_at"`
UpdatedAt *time.Time `form:"updated_at"`
}
Click to show internal directories.
Click to hide internal directories.