Documentation
¶
Index ¶
- Constants
- Variables
- func Amount(v int64) predicate.PaymentIntent
- func AmountEQ(v int64) predicate.PaymentIntent
- func AmountGT(v int64) predicate.PaymentIntent
- func AmountGTE(v int64) predicate.PaymentIntent
- func AmountIn(vs ...int64) predicate.PaymentIntent
- func AmountLT(v int64) predicate.PaymentIntent
- func AmountLTE(v int64) predicate.PaymentIntent
- func AmountNEQ(v int64) predicate.PaymentIntent
- func AmountNotIn(vs ...int64) predicate.PaymentIntent
- func And(predicates ...predicate.PaymentIntent) predicate.PaymentIntent
- func ClientSecret(v string) predicate.PaymentIntent
- func ClientSecretContains(v string) predicate.PaymentIntent
- func ClientSecretContainsFold(v string) predicate.PaymentIntent
- func ClientSecretEQ(v string) predicate.PaymentIntent
- func ClientSecretEqualFold(v string) predicate.PaymentIntent
- func ClientSecretGT(v string) predicate.PaymentIntent
- func ClientSecretGTE(v string) predicate.PaymentIntent
- func ClientSecretHasPrefix(v string) predicate.PaymentIntent
- func ClientSecretHasSuffix(v string) predicate.PaymentIntent
- func ClientSecretIn(vs ...string) predicate.PaymentIntent
- func ClientSecretIsNil() predicate.PaymentIntent
- func ClientSecretLT(v string) predicate.PaymentIntent
- func ClientSecretLTE(v string) predicate.PaymentIntent
- func ClientSecretNEQ(v string) predicate.PaymentIntent
- func ClientSecretNotIn(vs ...string) predicate.PaymentIntent
- func ClientSecretNotNil() predicate.PaymentIntent
- func CreatedAt(v time.Time) predicate.PaymentIntent
- func CreatedAtEQ(v time.Time) predicate.PaymentIntent
- func CreatedAtGT(v time.Time) predicate.PaymentIntent
- func CreatedAtGTE(v time.Time) predicate.PaymentIntent
- func CreatedAtIn(vs ...time.Time) predicate.PaymentIntent
- func CreatedAtLT(v time.Time) predicate.PaymentIntent
- func CreatedAtLTE(v time.Time) predicate.PaymentIntent
- func CreatedAtNEQ(v time.Time) predicate.PaymentIntent
- func CreatedAtNotIn(vs ...time.Time) predicate.PaymentIntent
- func Currency(v string) predicate.PaymentIntent
- func CurrencyContains(v string) predicate.PaymentIntent
- func CurrencyContainsFold(v string) predicate.PaymentIntent
- func CurrencyEQ(v string) predicate.PaymentIntent
- func CurrencyEqualFold(v string) predicate.PaymentIntent
- func CurrencyGT(v string) predicate.PaymentIntent
- func CurrencyGTE(v string) predicate.PaymentIntent
- func CurrencyHasPrefix(v string) predicate.PaymentIntent
- func CurrencyHasSuffix(v string) predicate.PaymentIntent
- func CurrencyIn(vs ...string) predicate.PaymentIntent
- func CurrencyLT(v string) predicate.PaymentIntent
- func CurrencyLTE(v string) predicate.PaymentIntent
- func CurrencyNEQ(v string) predicate.PaymentIntent
- func CurrencyNotIn(vs ...string) predicate.PaymentIntent
- func Description(v string) predicate.PaymentIntent
- func DescriptionContains(v string) predicate.PaymentIntent
- func DescriptionContainsFold(v string) predicate.PaymentIntent
- func DescriptionEQ(v string) predicate.PaymentIntent
- func DescriptionEqualFold(v string) predicate.PaymentIntent
- func DescriptionGT(v string) predicate.PaymentIntent
- func DescriptionGTE(v string) predicate.PaymentIntent
- func DescriptionHasPrefix(v string) predicate.PaymentIntent
- func DescriptionHasSuffix(v string) predicate.PaymentIntent
- func DescriptionIn(vs ...string) predicate.PaymentIntent
- func DescriptionIsNil() predicate.PaymentIntent
- func DescriptionLT(v string) predicate.PaymentIntent
- func DescriptionLTE(v string) predicate.PaymentIntent
- func DescriptionNEQ(v string) predicate.PaymentIntent
- func DescriptionNotIn(vs ...string) predicate.PaymentIntent
- func DescriptionNotNil() predicate.PaymentIntent
- func HasCustomer() predicate.PaymentIntent
- func HasCustomerWith(preds ...predicate.PaymentCustomer) predicate.PaymentIntent
- func ID(id int) predicate.PaymentIntent
- func IDEQ(id int) predicate.PaymentIntent
- func IDGT(id int) predicate.PaymentIntent
- func IDGTE(id int) predicate.PaymentIntent
- func IDIn(ids ...int) predicate.PaymentIntent
- func IDLT(id int) predicate.PaymentIntent
- func IDLTE(id int) predicate.PaymentIntent
- func IDNEQ(id int) predicate.PaymentIntent
- func IDNotIn(ids ...int) predicate.PaymentIntent
- func MetadataIsNil() predicate.PaymentIntent
- func MetadataNotNil() predicate.PaymentIntent
- func Not(p predicate.PaymentIntent) predicate.PaymentIntent
- func Or(predicates ...predicate.PaymentIntent) predicate.PaymentIntent
- func Provider(v string) predicate.PaymentIntent
- func ProviderContains(v string) predicate.PaymentIntent
- func ProviderContainsFold(v string) predicate.PaymentIntent
- func ProviderEQ(v string) predicate.PaymentIntent
- func ProviderEqualFold(v string) predicate.PaymentIntent
- func ProviderGT(v string) predicate.PaymentIntent
- func ProviderGTE(v string) predicate.PaymentIntent
- func ProviderHasPrefix(v string) predicate.PaymentIntent
- func ProviderHasSuffix(v string) predicate.PaymentIntent
- func ProviderIn(vs ...string) predicate.PaymentIntent
- func ProviderLT(v string) predicate.PaymentIntent
- func ProviderLTE(v string) predicate.PaymentIntent
- func ProviderNEQ(v string) predicate.PaymentIntent
- func ProviderNotIn(vs ...string) predicate.PaymentIntent
- func ProviderPaymentIntentID(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDContains(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDContainsFold(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDEQ(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDEqualFold(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDGT(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDGTE(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDHasPrefix(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDHasSuffix(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDIn(vs ...string) predicate.PaymentIntent
- func ProviderPaymentIntentIDLT(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDLTE(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDNEQ(v string) predicate.PaymentIntent
- func ProviderPaymentIntentIDNotIn(vs ...string) predicate.PaymentIntent
- func StatusEQ(v Status) predicate.PaymentIntent
- func StatusIn(vs ...Status) predicate.PaymentIntent
- func StatusNEQ(v Status) predicate.PaymentIntent
- func StatusNotIn(vs ...Status) predicate.PaymentIntent
- func StatusValidator(s Status) error
- func UpdatedAt(v time.Time) predicate.PaymentIntent
- func UpdatedAtEQ(v time.Time) predicate.PaymentIntent
- func UpdatedAtGT(v time.Time) predicate.PaymentIntent
- func UpdatedAtGTE(v time.Time) predicate.PaymentIntent
- func UpdatedAtIn(vs ...time.Time) predicate.PaymentIntent
- func UpdatedAtLT(v time.Time) predicate.PaymentIntent
- func UpdatedAtLTE(v time.Time) predicate.PaymentIntent
- func UpdatedAtNEQ(v time.Time) predicate.PaymentIntent
- func UpdatedAtNotIn(vs ...time.Time) predicate.PaymentIntent
- func ValidColumn(column string) bool
- type OrderOption
- func ByAmount(opts ...sql.OrderTermOption) OrderOption
- func ByClientSecret(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCurrency(opts ...sql.OrderTermOption) OrderOption
- func ByCustomerField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByDescription(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByProvider(opts ...sql.OrderTermOption) OrderOption
- func ByProviderPaymentIntentID(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- type Status
Constants ¶
const ( // Label holds the string label denoting the paymentintent type in the database. Label = "payment_intent" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldProviderPaymentIntentID holds the string denoting the provider_payment_intent_id field in the database. FieldProviderPaymentIntentID = "provider_payment_intent_id" // FieldProvider holds the string denoting the provider field in the database. FieldProvider = "provider" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldAmount holds the string denoting the amount field in the database. FieldAmount = "amount" // FieldCurrency holds the string denoting the currency field in the database. FieldCurrency = "currency" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldClientSecret holds the string denoting the client_secret field in the database. FieldClientSecret = "client_secret" // FieldMetadata holds the string denoting the metadata field in the database. FieldMetadata = "metadata" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeCustomer holds the string denoting the customer edge name in mutations. EdgeCustomer = "customer" // Table holds the table name of the paymentintent in the database. Table = "payment_intents" // CustomerTable is the table that holds the customer relation/edge. CustomerTable = "payment_intents" // CustomerInverseTable is the table name for the PaymentCustomer entity. // It exists in this package in order to avoid circular dependency with the "paymentcustomer" package. CustomerInverseTable = "payment_customers" // CustomerColumn is the table column denoting the customer relation/edge. CustomerColumn = "payment_customer_payment_intents" )
const DefaultStatus = StatusRequiresPaymentMethod
StatusRequiresPaymentMethod is the default value of the Status enum.
Variables ¶
var ( // ProviderPaymentIntentIDValidator is a validator for the "provider_payment_intent_id" field. It is called by the builders before save. ProviderPaymentIntentIDValidator func(string) error // DefaultProvider holds the default value on creation for the "provider" field. DefaultProvider string // ProviderValidator is a validator for the "provider" field. It is called by the builders before save. ProviderValidator func(string) error // AmountValidator is a validator for the "amount" field. It is called by the builders before save. AmountValidator func(int64) error // DefaultCurrency holds the default value on creation for the "currency" field. DefaultCurrency string // CurrencyValidator is a validator for the "currency" field. It is called by the builders before save. CurrencyValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time )
var Columns = []string{ FieldID, FieldProviderPaymentIntentID, FieldProvider, FieldStatus, FieldAmount, FieldCurrency, FieldDescription, FieldClientSecret, FieldMetadata, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for paymentintent fields.
var ForeignKeys = []string{
"payment_customer_payment_intents",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "payment_intents" table and are not defined as standalone fields in the schema.
Functions ¶
func Amount ¶
func Amount(v int64) predicate.PaymentIntent
Amount applies equality check predicate on the "amount" field. It's identical to AmountEQ.
func AmountEQ ¶
func AmountEQ(v int64) predicate.PaymentIntent
AmountEQ applies the EQ predicate on the "amount" field.
func AmountGT ¶
func AmountGT(v int64) predicate.PaymentIntent
AmountGT applies the GT predicate on the "amount" field.
func AmountGTE ¶
func AmountGTE(v int64) predicate.PaymentIntent
AmountGTE applies the GTE predicate on the "amount" field.
func AmountIn ¶
func AmountIn(vs ...int64) predicate.PaymentIntent
AmountIn applies the In predicate on the "amount" field.
func AmountLT ¶
func AmountLT(v int64) predicate.PaymentIntent
AmountLT applies the LT predicate on the "amount" field.
func AmountLTE ¶
func AmountLTE(v int64) predicate.PaymentIntent
AmountLTE applies the LTE predicate on the "amount" field.
func AmountNEQ ¶
func AmountNEQ(v int64) predicate.PaymentIntent
AmountNEQ applies the NEQ predicate on the "amount" field.
func AmountNotIn ¶
func AmountNotIn(vs ...int64) predicate.PaymentIntent
AmountNotIn applies the NotIn predicate on the "amount" field.
func And ¶
func And(predicates ...predicate.PaymentIntent) predicate.PaymentIntent
And groups predicates with the AND operator between them.
func ClientSecret ¶
func ClientSecret(v string) predicate.PaymentIntent
ClientSecret applies equality check predicate on the "client_secret" field. It's identical to ClientSecretEQ.
func ClientSecretContains ¶
func ClientSecretContains(v string) predicate.PaymentIntent
ClientSecretContains applies the Contains predicate on the "client_secret" field.
func ClientSecretContainsFold ¶
func ClientSecretContainsFold(v string) predicate.PaymentIntent
ClientSecretContainsFold applies the ContainsFold predicate on the "client_secret" field.
func ClientSecretEQ ¶
func ClientSecretEQ(v string) predicate.PaymentIntent
ClientSecretEQ applies the EQ predicate on the "client_secret" field.
func ClientSecretEqualFold ¶
func ClientSecretEqualFold(v string) predicate.PaymentIntent
ClientSecretEqualFold applies the EqualFold predicate on the "client_secret" field.
func ClientSecretGT ¶
func ClientSecretGT(v string) predicate.PaymentIntent
ClientSecretGT applies the GT predicate on the "client_secret" field.
func ClientSecretGTE ¶
func ClientSecretGTE(v string) predicate.PaymentIntent
ClientSecretGTE applies the GTE predicate on the "client_secret" field.
func ClientSecretHasPrefix ¶
func ClientSecretHasPrefix(v string) predicate.PaymentIntent
ClientSecretHasPrefix applies the HasPrefix predicate on the "client_secret" field.
func ClientSecretHasSuffix ¶
func ClientSecretHasSuffix(v string) predicate.PaymentIntent
ClientSecretHasSuffix applies the HasSuffix predicate on the "client_secret" field.
func ClientSecretIn ¶
func ClientSecretIn(vs ...string) predicate.PaymentIntent
ClientSecretIn applies the In predicate on the "client_secret" field.
func ClientSecretIsNil ¶
func ClientSecretIsNil() predicate.PaymentIntent
ClientSecretIsNil applies the IsNil predicate on the "client_secret" field.
func ClientSecretLT ¶
func ClientSecretLT(v string) predicate.PaymentIntent
ClientSecretLT applies the LT predicate on the "client_secret" field.
func ClientSecretLTE ¶
func ClientSecretLTE(v string) predicate.PaymentIntent
ClientSecretLTE applies the LTE predicate on the "client_secret" field.
func ClientSecretNEQ ¶
func ClientSecretNEQ(v string) predicate.PaymentIntent
ClientSecretNEQ applies the NEQ predicate on the "client_secret" field.
func ClientSecretNotIn ¶
func ClientSecretNotIn(vs ...string) predicate.PaymentIntent
ClientSecretNotIn applies the NotIn predicate on the "client_secret" field.
func ClientSecretNotNil ¶
func ClientSecretNotNil() predicate.PaymentIntent
ClientSecretNotNil applies the NotNil predicate on the "client_secret" field.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.PaymentIntent
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.PaymentIntent
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.PaymentIntent
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.PaymentIntent
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.PaymentIntent
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.PaymentIntent
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.PaymentIntent
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.PaymentIntent
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.PaymentIntent
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Currency ¶
func Currency(v string) predicate.PaymentIntent
Currency applies equality check predicate on the "currency" field. It's identical to CurrencyEQ.
func CurrencyContains ¶
func CurrencyContains(v string) predicate.PaymentIntent
CurrencyContains applies the Contains predicate on the "currency" field.
func CurrencyContainsFold ¶
func CurrencyContainsFold(v string) predicate.PaymentIntent
CurrencyContainsFold applies the ContainsFold predicate on the "currency" field.
func CurrencyEQ ¶
func CurrencyEQ(v string) predicate.PaymentIntent
CurrencyEQ applies the EQ predicate on the "currency" field.
func CurrencyEqualFold ¶
func CurrencyEqualFold(v string) predicate.PaymentIntent
CurrencyEqualFold applies the EqualFold predicate on the "currency" field.
func CurrencyGT ¶
func CurrencyGT(v string) predicate.PaymentIntent
CurrencyGT applies the GT predicate on the "currency" field.
func CurrencyGTE ¶
func CurrencyGTE(v string) predicate.PaymentIntent
CurrencyGTE applies the GTE predicate on the "currency" field.
func CurrencyHasPrefix ¶
func CurrencyHasPrefix(v string) predicate.PaymentIntent
CurrencyHasPrefix applies the HasPrefix predicate on the "currency" field.
func CurrencyHasSuffix ¶
func CurrencyHasSuffix(v string) predicate.PaymentIntent
CurrencyHasSuffix applies the HasSuffix predicate on the "currency" field.
func CurrencyIn ¶
func CurrencyIn(vs ...string) predicate.PaymentIntent
CurrencyIn applies the In predicate on the "currency" field.
func CurrencyLT ¶
func CurrencyLT(v string) predicate.PaymentIntent
CurrencyLT applies the LT predicate on the "currency" field.
func CurrencyLTE ¶
func CurrencyLTE(v string) predicate.PaymentIntent
CurrencyLTE applies the LTE predicate on the "currency" field.
func CurrencyNEQ ¶
func CurrencyNEQ(v string) predicate.PaymentIntent
CurrencyNEQ applies the NEQ predicate on the "currency" field.
func CurrencyNotIn ¶
func CurrencyNotIn(vs ...string) predicate.PaymentIntent
CurrencyNotIn applies the NotIn predicate on the "currency" field.
func Description ¶
func Description(v string) predicate.PaymentIntent
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
func DescriptionContains(v string) predicate.PaymentIntent
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
func DescriptionContainsFold(v string) predicate.PaymentIntent
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
func DescriptionEQ(v string) predicate.PaymentIntent
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
func DescriptionEqualFold(v string) predicate.PaymentIntent
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
func DescriptionGT(v string) predicate.PaymentIntent
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
func DescriptionGTE(v string) predicate.PaymentIntent
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
func DescriptionHasPrefix(v string) predicate.PaymentIntent
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
func DescriptionHasSuffix(v string) predicate.PaymentIntent
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
func DescriptionIn(vs ...string) predicate.PaymentIntent
DescriptionIn applies the In predicate on the "description" field.
func DescriptionIsNil ¶
func DescriptionIsNil() predicate.PaymentIntent
DescriptionIsNil applies the IsNil predicate on the "description" field.
func DescriptionLT ¶
func DescriptionLT(v string) predicate.PaymentIntent
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
func DescriptionLTE(v string) predicate.PaymentIntent
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
func DescriptionNEQ(v string) predicate.PaymentIntent
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
func DescriptionNotIn(vs ...string) predicate.PaymentIntent
DescriptionNotIn applies the NotIn predicate on the "description" field.
func DescriptionNotNil ¶
func DescriptionNotNil() predicate.PaymentIntent
DescriptionNotNil applies the NotNil predicate on the "description" field.
func HasCustomer ¶
func HasCustomer() predicate.PaymentIntent
HasCustomer applies the HasEdge predicate on the "customer" edge.
func HasCustomerWith ¶
func HasCustomerWith(preds ...predicate.PaymentCustomer) predicate.PaymentIntent
HasCustomerWith applies the HasEdge predicate on the "customer" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id int) predicate.PaymentIntent
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int) predicate.PaymentIntent
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int) predicate.PaymentIntent
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.PaymentIntent
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int) predicate.PaymentIntent
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.PaymentIntent
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.PaymentIntent
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.PaymentIntent
IDNotIn applies the NotIn predicate on the ID field.
func MetadataIsNil ¶
func MetadataIsNil() predicate.PaymentIntent
MetadataIsNil applies the IsNil predicate on the "metadata" field.
func MetadataNotNil ¶
func MetadataNotNil() predicate.PaymentIntent
MetadataNotNil applies the NotNil predicate on the "metadata" field.
func Not ¶
func Not(p predicate.PaymentIntent) predicate.PaymentIntent
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.PaymentIntent) predicate.PaymentIntent
Or groups predicates with the OR operator between them.
func Provider ¶
func Provider(v string) predicate.PaymentIntent
Provider applies equality check predicate on the "provider" field. It's identical to ProviderEQ.
func ProviderContains ¶
func ProviderContains(v string) predicate.PaymentIntent
ProviderContains applies the Contains predicate on the "provider" field.
func ProviderContainsFold ¶
func ProviderContainsFold(v string) predicate.PaymentIntent
ProviderContainsFold applies the ContainsFold predicate on the "provider" field.
func ProviderEQ ¶
func ProviderEQ(v string) predicate.PaymentIntent
ProviderEQ applies the EQ predicate on the "provider" field.
func ProviderEqualFold ¶
func ProviderEqualFold(v string) predicate.PaymentIntent
ProviderEqualFold applies the EqualFold predicate on the "provider" field.
func ProviderGT ¶
func ProviderGT(v string) predicate.PaymentIntent
ProviderGT applies the GT predicate on the "provider" field.
func ProviderGTE ¶
func ProviderGTE(v string) predicate.PaymentIntent
ProviderGTE applies the GTE predicate on the "provider" field.
func ProviderHasPrefix ¶
func ProviderHasPrefix(v string) predicate.PaymentIntent
ProviderHasPrefix applies the HasPrefix predicate on the "provider" field.
func ProviderHasSuffix ¶
func ProviderHasSuffix(v string) predicate.PaymentIntent
ProviderHasSuffix applies the HasSuffix predicate on the "provider" field.
func ProviderIn ¶
func ProviderIn(vs ...string) predicate.PaymentIntent
ProviderIn applies the In predicate on the "provider" field.
func ProviderLT ¶
func ProviderLT(v string) predicate.PaymentIntent
ProviderLT applies the LT predicate on the "provider" field.
func ProviderLTE ¶
func ProviderLTE(v string) predicate.PaymentIntent
ProviderLTE applies the LTE predicate on the "provider" field.
func ProviderNEQ ¶
func ProviderNEQ(v string) predicate.PaymentIntent
ProviderNEQ applies the NEQ predicate on the "provider" field.
func ProviderNotIn ¶
func ProviderNotIn(vs ...string) predicate.PaymentIntent
ProviderNotIn applies the NotIn predicate on the "provider" field.
func ProviderPaymentIntentID ¶
func ProviderPaymentIntentID(v string) predicate.PaymentIntent
ProviderPaymentIntentID applies equality check predicate on the "provider_payment_intent_id" field. It's identical to ProviderPaymentIntentIDEQ.
func ProviderPaymentIntentIDContains ¶
func ProviderPaymentIntentIDContains(v string) predicate.PaymentIntent
ProviderPaymentIntentIDContains applies the Contains predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDContainsFold ¶
func ProviderPaymentIntentIDContainsFold(v string) predicate.PaymentIntent
ProviderPaymentIntentIDContainsFold applies the ContainsFold predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDEQ ¶
func ProviderPaymentIntentIDEQ(v string) predicate.PaymentIntent
ProviderPaymentIntentIDEQ applies the EQ predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDEqualFold ¶
func ProviderPaymentIntentIDEqualFold(v string) predicate.PaymentIntent
ProviderPaymentIntentIDEqualFold applies the EqualFold predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDGT ¶
func ProviderPaymentIntentIDGT(v string) predicate.PaymentIntent
ProviderPaymentIntentIDGT applies the GT predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDGTE ¶
func ProviderPaymentIntentIDGTE(v string) predicate.PaymentIntent
ProviderPaymentIntentIDGTE applies the GTE predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDHasPrefix ¶
func ProviderPaymentIntentIDHasPrefix(v string) predicate.PaymentIntent
ProviderPaymentIntentIDHasPrefix applies the HasPrefix predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDHasSuffix ¶
func ProviderPaymentIntentIDHasSuffix(v string) predicate.PaymentIntent
ProviderPaymentIntentIDHasSuffix applies the HasSuffix predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDIn ¶
func ProviderPaymentIntentIDIn(vs ...string) predicate.PaymentIntent
ProviderPaymentIntentIDIn applies the In predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDLT ¶
func ProviderPaymentIntentIDLT(v string) predicate.PaymentIntent
ProviderPaymentIntentIDLT applies the LT predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDLTE ¶
func ProviderPaymentIntentIDLTE(v string) predicate.PaymentIntent
ProviderPaymentIntentIDLTE applies the LTE predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDNEQ ¶
func ProviderPaymentIntentIDNEQ(v string) predicate.PaymentIntent
ProviderPaymentIntentIDNEQ applies the NEQ predicate on the "provider_payment_intent_id" field.
func ProviderPaymentIntentIDNotIn ¶
func ProviderPaymentIntentIDNotIn(vs ...string) predicate.PaymentIntent
ProviderPaymentIntentIDNotIn applies the NotIn predicate on the "provider_payment_intent_id" field.
func StatusEQ ¶
func StatusEQ(v Status) predicate.PaymentIntent
StatusEQ applies the EQ predicate on the "status" field.
func StatusIn ¶
func StatusIn(vs ...Status) predicate.PaymentIntent
StatusIn applies the In predicate on the "status" field.
func StatusNEQ ¶
func StatusNEQ(v Status) predicate.PaymentIntent
StatusNEQ applies the NEQ predicate on the "status" field.
func StatusNotIn ¶
func StatusNotIn(vs ...Status) predicate.PaymentIntent
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusValidator ¶
StatusValidator is a validator for the "status" field enum values. It is called by the builders before save.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.PaymentIntent
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.PaymentIntent
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.PaymentIntent
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.PaymentIntent
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.PaymentIntent
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.PaymentIntent
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.PaymentIntent
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.PaymentIntent
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.PaymentIntent
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the PaymentIntent queries.
func ByAmount ¶
func ByAmount(opts ...sql.OrderTermOption) OrderOption
ByAmount orders the results by the amount field.
func ByClientSecret ¶
func ByClientSecret(opts ...sql.OrderTermOption) OrderOption
ByClientSecret orders the results by the client_secret field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCurrency ¶
func ByCurrency(opts ...sql.OrderTermOption) OrderOption
ByCurrency orders the results by the currency field.
func ByCustomerField ¶
func ByCustomerField(field string, opts ...sql.OrderTermOption) OrderOption
ByCustomerField orders the results by customer field.
func ByDescription ¶
func ByDescription(opts ...sql.OrderTermOption) OrderOption
ByDescription orders the results by the description field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByProvider ¶
func ByProvider(opts ...sql.OrderTermOption) OrderOption
ByProvider orders the results by the provider field.
func ByProviderPaymentIntentID ¶
func ByProviderPaymentIntentID(opts ...sql.OrderTermOption) OrderOption
ByProviderPaymentIntentID orders the results by the provider_payment_intent_id field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
type Status ¶
type Status string
Status defines the type for the "status" enum field.
const ( StatusRequiresPaymentMethod Status = "requires_payment_method" StatusRequiresConfirmation Status = "requires_confirmation" StatusRequiresAction Status = "requires_action" StatusProcessing Status = "processing" StatusRequiresCapture Status = "requires_capture" StatusCanceled Status = "canceled" StatusSucceeded Status = "succeeded" )
Status values.